@@ -494,7 +494,7 @@ void config_reload( ){
 	make_uint(&cfg_secure_action,			conf_secure_action,				2,		0);					// default: 0	lock&blank
 	make_uint(&cfg_secure_power_action,		conf_secure_power_action,		1,		0);					// default: 0	lock&blank
 	make_bool(&cfg_secure_button,			conf_secure_button,				0,		HW_THEME);			// default: 0	don't show secure button
-	make_uint(&cfg_power_unlock_key,		conf_power_unlock_key,			1,		0);					// default: 1	power button + fullscreen key unlocks
+	make_uint(&cfg_power_unlock_key,		conf_power_unlock_key,		(is_810 ? 1:4),	0);				// default: 1/4	power button + fullscreen/dpad key unlocks
 	// user interface
 	make_bool(&cfg_service_size_unit,		conf_service_size_unit,			1,		HW_THEME);			// default: 1	show MB with service sizes
 	make_bool(&cfg_short_tap_markers,		conf_short_tap_markers,			0,		HW_THEME);			// default: 0	don't show short tap markers
