@@ -448,26 +448,6 @@ acting_dead_state = 0;
 		}
 		return DBUS_HANDLER_RESULT_HANDLED;
 
-	} else if(dbus_message_is_signal(message, "com.nokia.mce.signal", "system_inactivity_ind")){
-		unsigned state;
-
-		debug_write("[DBUS] signal: com.nokia.mce.signal.system_inactivity_ind");
-
-		if(dbus_message_get_args(message, &dbus_error, _BOOL_, &state, _END_)){
-			if(state && !hw_device_locked && !use_minimal_ui){
-				if(!is_idle){
-					if(conf_get_bool("/system/osso/dsm/locks/devicelock_autolock_enabled")){
-						test_write("device is idle, start timer...");
-						set_timer(&idle_timer, (double)conf_get_int("/system/osso/dsm/locks/devicelock_autolock_timeout")*60.0);
-						is_idle = 1;
-						dbus_send_wakeup(_WAKEUP_REFRESH_); // get out of an infinite timeout
-					}
-				}
-			} else
-				is_idle = 0;
-		}
-		return DBUS_HANDLER_RESULT_HANDLED;
-
 	} else if(dbus_message_is_signal(message, "com.nokia.mce.signal", "shutdown_ind")){
 
 		debug_write("[DBUS] signal: com.nokia.mce.signal.shutdown_ind");
