@@ -43,7 +43,7 @@ s_hw_swap hw_swap;
 
 s_hw_screen hw_screen;
 unsigned hw_flight_mode;
-unsigned hw_device_locked, hw_device_autolocked, hw_device_autolock_map_state;
+unsigned hw_device_locked;
 
 s_hw_battery hw_battery;
 
@@ -240,9 +240,7 @@ static const char *_mce_device_NORMAL_ = "normal";
 static const char *_mce_device_FLIGHT_ = "flight";
 static unsigned got_flight_mode, sl_ready;
 
-static const char *_mce_get_devicelock_mode_ = "get_devicelock_mode"; // method
 static const char *_mce_devlock_callback_ = "devlock_callback"; // method
-static const char *_mce_device_LOCKED_ = "locked";
 
 #define TOUCHSCREEN_CONTROL "/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_ts"
 
@@ -319,26 +317,6 @@ static void mce_get_flight_callback( DBusPendingCall *pending, void *user_data )
 	}
 	dbus_message_unref(message);
 }
-
-static void mce_get_devicelock_callback( DBusPendingCall *pending, void *user_data ){
-	DBusMessage *message = dbus_pending_call_steal_reply(pending);
-	dbus_pending_call_unref(pending);
-	char *mode;
-	debug_write("[DBUS] callback: mce_get_devicelock_callback");
-	if(dbus_message_get_args(message, &dbus_error, _STRING_, &mode, _END_)){
-		unsigned locked = (strcmp(mode, _mce_device_LOCKED_) ? 0 : 1);
-		if(hw_device_locked != locked){
-			if(locked && !cfg_start_visible){
-				hw_device_autolocked = 1;
-				hw_device_autolock_map_state = 0; // ASUI started up in locked state but should unmap after code is entered
-			}
-			hw_device_locked = locked;
-			dbus_send_wakeup(_WAKEUP_DEVICE_LOCK_);
-		}
-		hw_initialized &= ~HWIS_MCE_DEVICELOCK;
-	}
-	dbus_message_unref(message);
-}
 #endif
 
 void mce_init( ){
@@ -350,7 +328,6 @@ void mce_init( ){
 	hw_screen.locked = 0;
 	hw_flight_mode = 0;
 	hw_device_locked = 0;
-	hw_device_autolocked = 0;
 
 	#ifdef ARCH_armel
 	sl_ready = 0;
@@ -362,11 +339,10 @@ void mce_init( ){
 //	hw_unlock_keys(); // unlock the keypad to match the current hw_screen.locked state, will be relocked by mce_get_tklock_callback()
 
 	if(!use_minimal_ui){
-		hw_initialized |= HWIS_MCE_DISPLAY|HWIS_MCE_LOCK|HWIS_MCE_FLIGHT|HWIS_MCE_DEVICELOCK;
+		hw_initialized |= HWIS_MCE_DISPLAY|HWIS_MCE_LOCK|HWIS_MCE_FLIGHT;
 		dbus_recv_method(mce_get_display_callback, _mce_service_, _mce_path_, _mce_interface_, _mce_get_display_status_, _END_);
 		dbus_recv_method(mce_get_tklock_callback, _mce_service_, _mce_path_, _mce_interface_, _mce_get_tklock_mode_, _END_);
 		dbus_recv_method(mce_get_flight_callback, _mce_service_, _mce_path_, _mce_interface_, _mce_get_device_mode_, _END_);
-		dbus_recv_method(mce_get_devicelock_callback, _mce_service_, _mce_path_, _mce_interface_, _mce_get_devicelock_mode_, _END_);
 	} else
 		hw_screen.locked = 1;
 	#endif
@@ -1454,8 +1430,6 @@ void hw_refresh( ){
 			dbus_recv_method(mce_get_tklock_callback, _mce_service_, _mce_path_, _mce_interface_, _mce_get_tklock_mode_, _END_);
 		if(hw_initialized & HWIS_MCE_FLIGHT)
 			dbus_recv_method(mce_get_flight_callback, _mce_service_, _mce_path_, _mce_interface_, _mce_get_device_mode_, _END_);
-		if(hw_initialized & HWIS_MCE_DEVICELOCK)
-			dbus_recv_method(mce_get_devicelock_callback, _mce_service_, _mce_path_, _mce_interface_, _mce_get_devicelock_mode_, _END_);
 
 		// BME
 		if(hw_initialized & HWIS_BME_CHARGER)
