@@ -86,17 +86,16 @@ typedef struct s_hw_usb {
 #define HWIS_MCE_DISPLAY (1<<0)
 #define HWIS_MCE_LOCK (1<<1)
 #define HWIS_MCE_FLIGHT (1<<2)
-#define HWIS_MCE_DEVICELOCK (1<<3)
-#define HWIS_BME_CHARGER (1<<4)
-#define HWIS_BME_MAX (1<<5)
-#define HWIS_BME_CAPACITY (1<<6)
-#define HWIS_BME_ACTIVE (1<<7)
-#define HWIS_BLUETOOTH_MODE (1<<8)
-#define HWIS_BLUETOOTH_NAME (1<<9)
-#define HWIS_BLUETOOTH_DEVICES (1<<10)
-#define HWIS_BLUETOOTH_HEADSET (1<<11)
-#define HWIS_WIFI_MODE (1<<12)
-#define HWIS_WIFI_STATE (1<<13)
+#define HWIS_BME_CHARGER (1<<3)
+#define HWIS_BME_MAX (1<<4)
+#define HWIS_BME_CAPACITY (1<<5)
+#define HWIS_BME_ACTIVE (1<<6)
+#define HWIS_BLUETOOTH_MODE (1<<7)
+#define HWIS_BLUETOOTH_NAME (1<<8)
+#define HWIS_BLUETOOTH_DEVICES (1<<9)
+#define HWIS_BLUETOOTH_HEADSET (1<<10)
+#define HWIS_WIFI_MODE (1<<11)
+#define HWIS_WIFI_STATE (1<<12)
 extern unsigned hw_initialized;
 
 #define HW_BRIGHTNESS (1<<0)
@@ -125,7 +124,7 @@ extern s_hw_memory hw_memory;
 extern s_hw_swap hw_swap;
 extern s_hw_screen hw_screen;
 extern unsigned hw_flight_mode;
-extern unsigned hw_device_locked, hw_device_autolocked, hw_device_autolock_map_state;
+extern unsigned hw_device_locked;
 extern s_hw_battery hw_battery;
 extern s_hw_cpu hw_cpu;
 extern s_hw_bluetooth hw_bluetooth;
