@@ -104,10 +104,6 @@ unsigned brightness_widget_page, volume_widget_page, battery_widget_page;
 unsigned flightmode_button_page, keyrepeat_button_page, screenstayslit_button_page, screenautolock_button_page;
 		// new *_page variables must be added to window_map() and dialog_reset()
 
-// idle timer to autolock device
-s_timer idle_timer;
-unsigned is_idle;
-
 unsigned power_unlock_keys[] = {0, KEYCODE_FULLSCREEN, KEYCODE_HOME, KEYCODE_ESCAPE, KEYCODE_DPAD_CENTER, KEYCODE_MENU};
 char *power_unlock_messages[] = {"",
 	"Press FULLSCREEN key to unlock", "Press HOME key to unlock", "Press ESCAPE key to unlock",
@@ -975,27 +971,21 @@ void press_lock_button( unsigned action ){
 	case 0: // not bound
 		break;
 	case 1: // lock
-		if(cfg_lock_and_close && !hw_device_autolocked) window_unmap();
+		if(cfg_lock_and_close) window_unmap();
 		mce_lock_screen(1);
 		break;
 	case 2: // lock&blank
-		if(cfg_lock_and_close && !hw_device_autolocked) window_unmap();
+		if(cfg_lock_and_close) window_unmap();
 		mce_lock_and_blank_screen();
 		break;
 	case 3: // blank
-		if(cfg_lock_and_close && !hw_device_autolocked) window_unmap();
+		if(cfg_lock_and_close) window_unmap();
 		mce_blank_screen();
 		break;
 	case 4: // secure
 		if(cfg_secure_button){
-			mce_lock_device();
-
-			if(cfg_lock_and_close){
-				hw_device_autolocked = 1;
-				hw_device_autolock_map_state = 0; // unmap after code is entered
-			}
-
 			press_lock_button(cfg_secure_action);
+			mce_lock_device();
 		}
 		break;
 	}
@@ -1168,11 +1158,15 @@ void detect_runlevel_transition( ){
 			#ifdef DEBUG
 			debug_runlevel = runlevel;
 			#endif
+			if(hw_device_locked || cfg_start_visible) draw_window(1);
+			else window_unmap();
 		}
 	}
 }
 
 int main( int argc, char *argv[] ){
+	unsigned devlock_map_state = 0;
+
 	// detect runlevel
 	int runlevel = 0;
 	{
@@ -1365,7 +1359,6 @@ if(runlevel == 2){
 	set_timer(&key_timer, BUTTON_CHECK_PERIOD);																keypress.key_down = 0; /* global */
 	set_timer(&brightness_timer, BRIGHTNESS_CHECK_PERIOD);
 	/* global motion_timer, don't need to clear it */			motion_callback = NULL; /* global */		unsigned has_motion = 0;
-	is_idle = 0;
 
 	double_tap_data.zone = Z_NULL; /* static global */
 
@@ -1734,6 +1727,7 @@ if(runlevel == 2){
 							usleep(500000); // sleep 500ms
 							goto exit;
 						} else {
+							devlock_map_state = window.is_mapped; // save window state
 							if(!window.is_mapped)
 								window_map();
 							if(current_dialog_draw != draw_fullsreen_clock && current_dialog_draw != draw_flashlight && current_dialog_draw != draw_alarm)
@@ -1742,10 +1736,7 @@ if(runlevel == 2){
 					} else {
 						debug_write("    message DEVICE UNLOCK");
 						secureHideKeypad();
-						if(hw_device_autolocked){
-							hw_device_autolocked = 0;
-							if(!hw_device_autolock_map_state) window_unmap();
-						}
+						if(!devlock_map_state) window_unmap(); // restore window state
 					}
 					break;
 
@@ -2022,21 +2013,6 @@ if(runlevel == 2){
 		if(hw_changes && (current_dialog_draw == NULL || hw_changes & (HW_THEME|HW_CPU|HW_BATTERY|HW_TEMPERATURE)))
 			draw_window(0);
 
-		if(is_idle){
-			if(is_timer_ready(&idle_timer)){
-				// device has exceeded the devicelock autolock timeout, lock device
-				test_write("timeout expired, locking device...");
-				mce_lock_device();
-				hw_device_autolocked = 1;
-				hw_device_autolock_map_state = window.is_mapped;
-				is_idle = 0;
-			} else if(infinite_timeout){
-				next_timer_duration = idle_timer.remaining;
-				infinite_timeout = 0;
-			} else if(next_timer_duration <= 0.0 || idle_timer.remaining < next_timer_duration)
-				next_timer_duration = idle_timer.remaining;
-		}
-
 	}
 
 	////////////////////
