@@ -78,9 +78,6 @@ extern s_selected_cell selected_cell;
 extern unsigned brightness_widget_page, volume_widget_page, battery_widget_page;
 extern unsigned flightmode_button_page, keyrepeat_button_page, screenstayslit_button_page, screenautolock_button_page;
 
-extern s_timer idle_timer;
-extern unsigned is_idle;
-
 extern unsigned power_unlock_keys[];
 extern char *power_unlock_messages[];
 
