@@ -36,6 +36,8 @@ unsigned svc_vpn_installed;
 unsigned svc_process_viewer, svc_nr_processes;
 s_process *svc_process_list;
 
+double last_svc_refresh;
+
 ////////////////////////////////////////////////////////////////////////// LOCAL GLOBALS
 
 typedef struct s_service {
@@ -107,7 +109,6 @@ void svc_init( ){
 }
 
 void svc_refresh( ){
-	DIR *proc;
 	unsigned sc_bluetooth_size = 0, sc_gps_size = 0, sc_wifi_size = 0, sc_audio_size = 0;
 	unsigned sc_desktop_size = 0, sc_desktop = 0;
 	unsigned nr_ssh_clients = 0;
@@ -227,6 +228,7 @@ void svc_refresh( ){
 	svc_vpn_installed = tmp_status;
 
 	// query running services
+	DIR *proc;
 	if((proc = opendir("/proc")) != NULL){
 		struct dirent *file;
 		s_process *process;
@@ -239,7 +241,7 @@ void svc_refresh( ){
 		while((file = readdir(proc))){
 			if(file->d_name[0] > '0' && file->d_name[0] <= '9'){
 				char filepath[30], command[PATH_MAX], cmdline[400], state;
-				unsigned ticks = 0, rss = 0, is_service = 0, is_shell = 0;
+				unsigned ticks = 0, rss = 0, is_service = 0, is_shell = 0, is_python = 0;
 				FILE *p;
 
 				// state, resident set size and cpu%
@@ -260,6 +262,7 @@ void svc_refresh( ){
 						fgets(cmdline, sizeof(cmdline), p);
 						fclose(p);
 						if(!strcmp(cmdline, "/bin/sh")) is_shell = 1;
+						else if(!strncmp(cmdline, "/usr/bin/python", 15)) is_python = 1;
 					} else cmdline[0] = '\0';
 				} else cmdline[0] = '\0';
 
@@ -268,6 +271,7 @@ void svc_refresh( ){
 					int i;
 					for(i = 0; services[i].name != NULL; i++){
 						s_service *s = &services[i];
+						// no python services, add a check here if any become known
 						if(is_shell){
 							if(!strcmp(command, s->name)){
 								if(s->running) *s->running = 1;
@@ -302,7 +306,7 @@ void svc_refresh( ){
 					sscanf(file->d_name, "%u", &pid);
 
 					// strip path from process name
-					if(cmdline[0] != '\0' && !is_shell){
+					if(cmdline[0] != '\0' && !is_shell && !is_python){
 						for(end = 0; cmdline[end] != '\0' && cmdline[end] != ' '; end++);
 						for(start = end; cmdline[start] != '/' && start > 0; start--);
 						if(cmdline[start] == '/') start++;
@@ -346,6 +350,8 @@ void svc_refresh( ){
 
 						if(is_shell)
 							snprintf(process->name, sizeof(process->name), "sh: %s", cmd);
+						else if(is_python)
+							snprintf(process->name, sizeof(process->name), "python: %s", cmd);
 						else
 							snprintf(process->name, sizeof(process->name), "%s", cmd);
 						process->state = state;
@@ -502,6 +508,8 @@ void svc_refresh( ){
 		svc_vpn_status = tmp_status;
 		svc_vpn_size = sc_vpn_size;
 	}
+
+	last_svc_refresh = current_time;
 }
 
 //////////////////////////////////////////////////////////////////////////
