@@ -13,6 +13,11 @@ static const char *battery_list4[] = {" percent free ", " percent used ", " free
 void battery_click_callback( GtkWidget *widget, gpointer data ){
 	new_section_vbox("Battery"); // add setting widgets to section_content_box
 
+	new_message("The statusbar applet can be a simple button to map ASUI or also show battery status.");
+	new_checkbox(conf_enable_battery_applet, "statusbar applet shows battery status", NULL);
+
+	new_separator();
+
 	new_message("Enabling this setting will cause the default statusbar battery applet to display its popup when ASUI is started."
 				" This should only happen right after the device is booted, when ASUI crash & restarts and when you enable this setting.");
 	new_checkbox(conf_battery_idle_time, "display battery idle time", NULL);
