@@ -1,13 +1,15 @@
 //	Advanced System UI
 //	Copyright (c) 2011 Brand Huntsman <brand.huntsman@gmail.com>
 
-#define ASUI_VERSION "0.5.0"
+#define ASUI_VERSION "0.5.4"
 
 /*
 /etc/init.d/hildon-desktop stop
 su - user -c "maemo-summoner /usr/bin/hildon-desktop.launch"
 */
 
+#include <string.h>
+
 #include <hildon/hildon-defines.h>
 #include <libhildondesktop/libhildondesktop.h>
 #include <libhildondesktop/statusbar-item.h>
@@ -22,6 +24,12 @@ su - user -c "maemo-summoner /usr/bin/hildon-desktop.launch"
 #include <gtk/gtk.h>
 #include <gdk/gdkpixbuf.h>
 
+#include <gconf/gconf-client.h>
+#define conf_get_bool(key) gconf_client_get_bool(p->gconf_client, key, (GError **)NULL)
+#define KEYNAME_PATH "/apps/asui"
+#define USE_BATTERY_KEYNAME "/enable_battery_applet"
+static const char *conf_enable_battery_applet = KEYNAME_PATH USE_BATTERY_KEYNAME;
+
 //////////////////////////////////////////////////////////////////////////
 
 G_BEGIN_DECLS
@@ -47,6 +55,8 @@ GType asui_battery_plugin_get_type(void);
 typedef struct {
 	osso_context_t *osso; // osso
 	DBusGConnection *connection; // system bus
+	unsigned use_battery; // show battery status
+	GConfClient *gconf_client; // gconf
 	GtkWidget *icon; // icon in button
 	GtkWidget *button; // button in statusbar
 } AsuiBatteryPluginPrivate;
@@ -71,6 +81,7 @@ static void asui_battery_plugin_class_init( AsuiBatteryPluginClass *klass ){
 
 static const char *charging_notification = "Charging...";
 static const char *battery_full_notification = "Battery Full";
+static const char *battery_low_notification = "Low Battery";
 
 static void display_notification( AsuiBatteryPluginPrivate *p, const char *msg ){
 	// initialize dbus
@@ -144,6 +155,7 @@ static gboolean asui_battery_open_asui( GtkButton *widget, GdkEventButton *butto
 typedef enum e_battery_status { BATTERY_DRAINING, BATTERY_CHARGING, BATTERY_AC } e_battery_status;
 static e_battery_status asui_battery_status;
 static unsigned asui_battery_capacity, asui_battery_initializing, asui_battery_init_timer, asui_battery_charging_cycle, asui_battery_charging_timer;
+static unsigned asui_battery_gconf_notify;
 
 static gboolean asui_battery_cycle_charging_icon( gpointer data ){
 	if(asui_battery_status == BATTERY_CHARGING){
@@ -159,7 +171,7 @@ static gboolean asui_battery_cycle_charging_icon( gpointer data ){
 }
 
 static void asui_battery_update_icon( AsuiBatteryPluginPrivate *p ){
-	if(asui_battery_initializing)
+	if(asui_battery_initializing || !p->use_battery)
 		asui_battery_set_icon("asui_power", p);
 	else switch(asui_battery_status){
 	case BATTERY_DRAINING:
@@ -206,6 +218,9 @@ static DBusHandlerResult asui_battery_signal_filter( DBusConnection *connection,
 			}
 		}
 		return DBUS_HANDLER_RESULT_HANDLED;
+	} else if(dbus_message_is_signal(message, "com.nokia.bme.signal", "battery_low")){
+		display_notification((AsuiBatteryPluginPrivate *)user_data, battery_low_notification);
+		return DBUS_HANDLER_RESULT_HANDLED;
 	} else if(dbus_message_is_signal(message, "com.nokia.bme.signal", "battery_full")){
 		display_notification((AsuiBatteryPluginPrivate *)user_data, battery_full_notification);
 		return DBUS_HANDLER_RESULT_HANDLED;
@@ -228,19 +243,67 @@ static gboolean asui_battery_req_battery_status( gpointer data ){
 
 //////////////////////////////////////////////////////////////////////////
 
-static void asui_battery_plugin_finalize( GObject *object ){
-	AsuiBatteryPluginPrivate *p = ASUI_BATTERY_PLUGIN_GET_PRIVATE(object);
-
+static void asui_battery_disable_battery( AsuiBatteryPluginPrivate *p ){
 	// remove timers
 	if(asui_battery_init_timer) g_source_remove(asui_battery_init_timer);
 	if(asui_battery_charging_timer) g_source_remove(asui_battery_charging_timer);
+
 	// remove dbus signal filter
 	DBusConnection *signal_bus = dbus_g_connection_get_connection(p->connection);
 	dbus_bus_remove_match(signal_bus, "type='signal',path='/com/qzx/asui',interface='com.qzx.asui'", NULL);
 	dbus_bus_remove_match(signal_bus, "type='signal',path='/com/nokia/bme/signal',interface='com.nokia.bme.signal'", NULL);
 	dbus_connection_flush(signal_bus);
 	dbus_connection_remove_filter(signal_bus, asui_battery_signal_filter, (void *)p);
+}
+
+static void asui_battery_enable_battery( AsuiBatteryPluginPrivate *p ){
+	// add dbus signal filter
+	DBusConnection *signal_bus = dbus_g_connection_get_connection(p->connection);
+	dbus_bus_add_match(signal_bus, "type='signal',path='/com/qzx/asui',interface='com.qzx.asui'", NULL);
+	dbus_bus_add_match(signal_bus, "type='signal',path='/com/nokia/bme/signal',interface='com.nokia.bme.signal'", NULL);
+	dbus_connection_flush(signal_bus);
+	dbus_connection_add_filter(signal_bus, asui_battery_signal_filter, (void *)p, NULL);
+
+	// initialize
+	asui_battery_status = BATTERY_DRAINING;
+	asui_battery_capacity = 0;
+	asui_battery_initializing = 3;
+	asui_battery_charging_timer = 0;
+	asui_battery_init_timer = g_timeout_add(2000, asui_battery_req_battery_status, (void *)p);
+	// 2 second wait before sending out first request
+}
+
+static void asui_battery_key_change_callback( GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer userData ){
+	const gchar *keyname = gconf_entry_get_key(entry);
+	if(keyname == NULL) return;
+	if(strcmp(keyname, conf_enable_battery_applet)) return;
+
+	AsuiBatteryPluginPrivate *p = (AsuiBatteryPluginPrivate *)userData;
+	unsigned use_battery = conf_get_bool(conf_enable_battery_applet);
+	if(use_battery != p->use_battery){
+		p->use_battery = use_battery;
+		if(use_battery){
+			asui_battery_enable_battery(p);
+		} else {
+			asui_battery_disable_battery(p);
+			asui_battery_update_icon(p);
+		}
+	}
+}
+
+//////////////////////////////////////////////////////////////////////////
+
+static void asui_battery_plugin_finalize( GObject *object ){
+	AsuiBatteryPluginPrivate *p = ASUI_BATTERY_PLUGIN_GET_PRIVATE(object);
+	GError *error = NULL;
+
+	gconf_client_remove_dir(p->gconf_client, KEYNAME_PATH, &error);
+	if(asui_battery_gconf_notify) gconf_client_notify_remove(p->gconf_client, asui_battery_gconf_notify);
+
+	if(p->use_battery) asui_battery_disable_battery(p);
+
 	dbus_g_connection_unref(p->connection);
+
 	// remove osso context
 	osso_deinitialize(p->osso);
 
@@ -263,11 +326,6 @@ static void asui_battery_plugin_init( AsuiBatteryPlugin *plugin ){
 		g_error_free(error);
 		return;
 	}
-	DBusConnection *signal_bus = dbus_g_connection_get_connection(p->connection);
-	dbus_bus_add_match(signal_bus, "type='signal',path='/com/qzx/asui',interface='com.qzx.asui'", NULL);
-	dbus_bus_add_match(signal_bus, "type='signal',path='/com/nokia/bme/signal',interface='com.nokia.bme.signal'", NULL);
-	dbus_connection_flush(signal_bus);
-	dbus_connection_add_filter(signal_bus, asui_battery_signal_filter, (void *)p, NULL);
 
 	p->icon = gtk_image_new_from_pixbuf(NULL);
 	asui_battery_set_icon("asui_power", p);
@@ -282,10 +340,12 @@ static void asui_battery_plugin_init( AsuiBatteryPlugin *plugin ){
 
 	gtk_widget_show_all(GTK_WIDGET(plugin));
 
-	asui_battery_status = BATTERY_DRAINING;
-	asui_battery_capacity = 0;
-	asui_battery_initializing = 3;
-	asui_battery_charging_timer = 0;
-	asui_battery_init_timer = g_timeout_add(2000, asui_battery_req_battery_status, (void *)p);
-	// 2 second wait before sending out first request
+	// initialize gconf
+	p->gconf_client = gconf_client_get_default();
+	if(p->gconf_client){
+		p->use_battery = conf_get_bool(conf_enable_battery_applet);
+		gconf_client_add_dir(p->gconf_client, KEYNAME_PATH, GCONF_CLIENT_PRELOAD_NONE, &error);
+		asui_battery_gconf_notify = gconf_client_notify_add(p->gconf_client, KEYNAME_PATH, asui_battery_key_change_callback, (void *)p, NULL, &error);
+		if(p->use_battery) asui_battery_enable_battery(p);
+	} else asui_battery_gconf_notify = 0;
 }
