@@ -29,6 +29,7 @@
 #include "hardware.h"
 #include "dialog.h"
 #include "dbus.h"
+#include "alarm.h"
 
 #include "images/button_toflightmode.xpm"
 #include "images/button_tonormalmode.xpm"
@@ -468,7 +469,7 @@ void window_map( ){
 	draw_window(1); // force
 
 	// open popup window if it has been more than 10 seconds since it was last closed
-	if(cfg_popup_onmap && current_time - popup_window_close_time > 10.0)
+	if(current_dialog_draw != draw_alarm && cfg_popup_onmap && current_time - popup_window_close_time > 10.0)
 		window_open_popup();
 }
 
@@ -1069,7 +1070,10 @@ void window_open_popup( ){
 		int x, y, w, h;
 
 		if(cfg_popup_fullscreen){ x = y = 0; w = window.width; h = window.height; }
-		else { x = (window.width>>1)-(POPUP_WIDTH/2); y = (window.height>>1)-(POPUP_HEIGHT/2)+50; w = POPUP_WIDTH; h = POPUP_HEIGHT; }
+		else {
+			x = (window.width>>1)-(POPUP_WIDTH/2); y = (window.height>>1)-(POPUP_HEIGHT/2)+(window.width > window.height ? 50 : 0);
+			w = POPUP_WIDTH; h = POPUP_HEIGHT;
+		}
 
 		popup_window = XCreateWindow(popup_display, DefaultRootWindow(popup_display), x,y, w,h,
 										0, CopyFromParent, CopyFromParent, CopyFromParent, 0, &winattr);
